<?php

namespace App\Http\Controllers\Frontend\Auth;

use App\Http\Controllers\Controller;
use App\Events\Frontend\Auth\UserRegistered;
use App\Mail\RequestApproval;
use App\Mail\RequestDemo;
use App\Models\Access\Invite;
use App\Models\Access\Profile;
use Illuminate\Foundation\Auth\RegistersUsers;
use App\Http\Requests\Frontend\Auth\RegisterRequest;
use App\Repositories\Frontend\Access\User\UserRepository;
use Illuminate\Http\Request;

/**
 * Class RegisterController.
 */
class RegisterController extends Controller
{
    use RegistersUsers;

    /**
     * @var UserRepository
     */
    protected $user;

    /**
     * RegisterController constructor.
     *
     * @param UserRepository $user
     */
    public function __construct(UserRepository $user)
    {
        // Where to redirect users after registering
        $this->redirectTo = '/login';

        $this->user = $user;
    }

    /**
     * Show the application registration form.
     *
     * @return \Illuminate\Http\Response
     */
    public function showRegistrationForm()
    {
        return view('frontend.auth.register');
    }

    /**
     * @param RegisterRequest $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function register(RegisterRequest $request)
    {
        if (config('access.users.confirm_email')){// || config('access.users.requires_approval')) {
            $user = $this->user->create($request->only('first_name', 'last_name', 'phonenumber', 'email', 'password'));

            event(new UserRegistered($user));

            return redirect($this->redirectPath())->withFlashSuccess(
//                config('access.users.requires_approval') ?
//                    trans('exceptions.frontend.auth.confirmation.created_pending') :
                    trans('exceptions.frontend.auth.confirmation.created_confirm')
            );
        } else {
            access()->login($this->user->create($request->only('first_name', 'last_name', 'phonenumber', 'email', 'password')));

            event(new UserRegistered(access()->user()));

//            $adminContact = "kurt.nguyen@qnexis.com";
//            $newUser = access()->user();
//
//            Mail::to($adminContact)->send(new RequestApproval($newUser));

            return redirect($this->redirectPath());
        }
    }

    public function showTos(Request $request)
    {
        return view('frontend.tos');
    }

    public function showPrivacy(Request $request)
    {
        return view('frontend.privacy');
    }
}
